export class X {
    constructor(){}
    bad(target__2: number) {
        const d__2 = 1;
        const min__2 = 0;
        const max__2 = 100;
        console.log('x', `duration ${d__2} not in range - ${min__2} ≥ ${d__2} && ${max__2} ≥ ${d__2}`);
    }
}
